@@ -17,7 +17,7 @@ require AutoLoader;
    NameSpace_URL
    NameSpace_X500
 );
-$VERSION = '0.11';
+$VERSION = '0.13';
 
 
 # Preloaded methods go here.
@@ -33,18 +33,17 @@ sub AUTOLOAD {
     croak "& not defined" if $constname eq 'constant';
     my $val = constant($constname, @_ ? $_[0] : 0);
     if ($! != 0) {
-	if ($! =~ /Invalid/ || $!{EINVAL}) {
-	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
-	    goto &AutoLoader::AUTOLOAD;
-	}
-	else {
-	    croak "Your vendor has not defined Data::UUID macro $constname";
-	}
+      if ($! =~ /Invalid/ || $!{EINVAL}) {
+        $AutoLoader::AUTOLOAD = $AUTOLOAD;
+        goto &AutoLoader::AUTOLOAD;
+      } else {
+        croak "Your vendor has not defined Data::UUID macro $constname";
+      }
     }
     {
-	no strict 'refs';
-	# Fixed between 5.005_53 and 5.005_61
-	*$AUTOLOAD = sub { $val };
+      no strict 'refs';
+      # Fixed between 5.005_53 and 5.005_61
+      *$AUTOLOAD = sub { $val };
     }
     goto &$AUTOLOAD;
 }
@@ -91,11 +90,11 @@ across network-connected systems.
 
 The algorithm for UUID generation, used by this extension, is described in the
 Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz
-(L<http://www.globecom.net/ietf/draft/draft-leach-uuids-guids-01.html>). It
-provides reasonably efficient and reliable framework for generating UUIDs and
-supports fairly high allocation rates -- 10 million per second per machine --
-and therefore is suitable for identifying both extremely short-lived and very
-persistent objects on a given system as well as across the network.
+(L<http://hegel.ittc.ku.edu/topics/internet/internet-drafts/draft-l/draft-leach-uuids-guids-01.txt>).
+It provides reasonably efficient and reliable framework for generating UUIDs
+and supports fairly high allocation rates -- 10 million per second per machine
+-- and therefore is suitable for identifying both extremely short-lived and
+very persistent objects on a given system as well as across the network.
 
 This modules provides several methods to create a UUID:
  
